pub struct MergeBranchPreviewOptions {
pub source_branch_id: String,
}Expand description
Options for previewing a merge from another branch into this session’s active branch.
Fields
source_branch_id: StringBranch whose changes would be merged into the active session branch.